// python wrapper for vtkMRMLSegmentationStorageNode
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkMRMLSegmentationStorageNode.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkMRMLSegmentationStorageNode(PyObject *dict); }
extern "C" { PyObject *PyvtkMRMLSegmentationStorageNode_ClassNew(); }

#ifndef DECLARED_PyvtkMRMLStorageNode_ClassNew
extern "C" { PyObject *PyvtkMRMLStorageNode_ClassNew(); }
#define DECLARED_PyvtkMRMLStorageNode_ClassNew
#endif

static const char *PyvtkMRMLSegmentationStorageNode_Doc =
  "vtkMRMLSegmentationStorageNode - MRML node for segmentation storage\non disk.\n\n"
  "Superclass: vtkMRMLStorageNode\n\n"
  "Storage nodes has methods to read/write segmentations to/from disk.\n\n"
  "Only the master representation of the segmentation is stored on disk.\n"
  "If master representation is labelmap then it is stored as a 4D image\n"
  "volume (.seg.nrrd file). If master representation is polygonal mesh,\n"
  "such as closed surface, then the segmentation is stored as a VTK\n"
  "multiblock data set (.vtm file accompanied by a number of .vtk\n"
  "polydata files).\n\n"
  "Specification of .seg.nrrd file:\n\n"
  "Segmentation is stored in a standard 4D NRRD image file (one \"list\"\n"
  "dimension and 3 spatial dimensions). Some additional metadata is\n"
  "stored in custom data fields (starting with Segmentation_ and\n"
  "SegmentN_ prefix), which provide hints on how the segments should be\n"
  "displayed or what they contain. Each 3D volume is a \"layer\" in the\n"
  "image can contain many non-overlapping segments. If no segments\n"
  "within the segmentation overlap, then the segmentation will be saved\n"
  "as a 3D volume. Upon saving, segments are automatically collapsed to\n"
  "as few layers as possible.\n\n"
  "Common custom fields:\n\n"
  "- Segmentation_ContainedRepresentationNames: names of segmentation\n"
  "  representations (separated by | character) that should be\n"
  "  displayed. Common representation names includ \"Binary labelmap\", \"Closed\n"
  "  surface\", \"Planar contours\", \"Fractional labelmap\"\n"
  "- Segmentation_ConversionParameters: parameters for algorithms that\n"
  "  compute requested representations. Each parameter definition is\n"
  "  separated by & character. A parameter definition consists of\n"
  "  parameter name, value, and description text, separated by |\n"
  "  character.\n"
  "- Segmentation_MasterRepresentation: defines what representation is\n"
  "  stored in the file. It is most commonly \"Binary labelmap\", but\n"
  "  there are other representations, too, which are stored in an image\n"
  "  volume - such as \"Fractional labelmap\".\n"
  "- Segmentation_ReferenceImageExtentOffset: This field allows storing\n"
  "  an image with arbitrary extent in a NRRD file. NRRD file only\n"
  "  stores size of the volume. This field stores voxel coordinates\n"
  "  (separated by spaces), therefore the extent can be computed as\n"
  "  (ReferenceImageExtentOffsetI, ReferenceImageExtentOffsetI+sizeI-1,\n"
  "  ReferenceImageExtentOffsetJ, ReferenceImageExtentOffsetJ+sizeJ-1,\n"
  "  ReferenceImageExtentOffsetK, ReferenceImageExtentOffsetk+sizeK-1).\n\n"
  "Custom fields for N-th segment (N is between 0 and size of the first\n"
  "axis - 1):\n\n"
  "- SegmentN_ID: identifier of the segment, it is unique within the\n"
  "  segmentation. Can be used for unanmiguously refer to a segment even\n"
  "if the segment's dispay name is changed.\n"
  "- SegmentN_Name: displayable name of the segment.\n"
  "- SegmentN_NameAutoGenerated: if value is 0 then it means that\n"
  "  SegmentN_Name was chosen manually by the user, if value is 1 then\n"
  "  it means that the segment's name is generated automatically (for\n"
  "  example, determined from terminology).\n"
  "- SegmentN_Color: recommended segment display color, defined with\n"
  "  red, green, blue values (between 0.0-1.0) separated by space\n"
  "  character\n"
  "- SegmentN_ColorAutoGenerated: if value is 0 then it means that\n"
  "  SegmentN_Color was chosen manually by the user, if value is 1 then\n"
  "  it means that the segment's color is generated automatically (for\n"
  "  example, color defined based on terminology).\n"
  "- SegmentN_Extent: 6 space-separated values (minI, maxI, minJ, maxJ,\n"
  "  minZ, maxZ) defining extent of non-empty region within the segment.\n"
  "- SegmentN_Tags: List of key:value pairs for storing additional\n"
  "  information about the segmen. Key:value pair is separated by a :\n"
  "  character, pairs are separated from each other by | character.\n"
  "- SegmentN_Layer: Index of the 3D volume that contains the segment.\n"
  "  For segmentations in which the segments do not overlap, the\n"
  "  segmentation can be represented as a single 3D volume with 1 layer.\n"
  "Upon saving, segments are automatically collapsed to as few layers as\n"
  "possible.\n"
  "- SegmentN_LabelValue: The scalar value used to represent the segment\n"
  "within its own layer. Segments on separate layers can have the same\n"
  "  label value.\n\n"
  "A frequently used key is \"TerminologyEntry\", which defines what the\n"
  "segment contains using DICOM compliant terminology. Value stores 7\n"
  "parts: terminology context name, category, type, type modifier,\n"
  "anatomic context name, anatomic region, and anatomic region modifier.\n"
  "Parts are separated from each other by ~ character. Five of these\n"
  "parts - category, type, type modifier, anatomic region, and anatomic\n"
  "region modifier are defined by a triplet of (coding scheme\n"
  "designator, code value, and code meaning). Components of the triplet\n"
  "are separated by ^ character.\n\n\n"
  "  Example: a mass in the right side of the adrenal gland would be\n"
  "encoded with the tag:\n\n\n"
  "  \"TerminologyEntry:\n"
  "   Segmentation category and type - 3D Slicer General Anatomy list\n"
  "   ~SCT^49755003^Morphologically Altered Structure\n"
  "   ~SCT^4147007^Mass\n"
  "   ~^^\n"
  "   ~Anatomic codes - DICOM master list\n"
  "   ~SCT^23451007^Adrenal gland\n"
  "   ~SCT^24028007^Right\"\n\n\n"
  "  Interpretation:\n\n"
  "- terminology context name: Segmentation category and type - 3D\n"
  "  Slicer General Anatomy list\n"
  "- category: codingScheme=SCT, codeValue=49755003,\n"
  "  codeMeaning=Morphologically Altered Structure\n"
  "- type: codingScheme=SCT, codeValue=4147007, codeMeaning=Mass\n"
  "- type modifier: not specified\n"
  "- anatomic context name: Anatomic codes - DICOM master list\n"
  "- anatomic region: codingScheme=SCT, codeValue=23451007,\n"
  "  codeMeaning=Adrenal gland\n"
  "- anatomic region modifier: codingScheme=SCT, codeValue=^24028007,\n"
  "  codeMeaning=Right\n\n";


static PyObject *
PyvtkMRMLSegmentationStorageNode_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkMRMLSegmentationStorageNode::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkMRMLSegmentationStorageNode::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkMRMLSegmentationStorageNode *tempr = vtkMRMLSegmentationStorageNode::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMRMLSegmentationStorageNode *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkMRMLSegmentationStorageNode::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkMRMLSegmentationStorageNode::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkMRMLSegmentationStorageNode::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_CreateNodeInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateNodeInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMRMLNode *tempr = (ap.IsBound() ?
      op->CreateNodeInstance() :
      op->vtkMRMLSegmentationStorageNode::CreateNodeInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_Copy(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Copy");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  vtkMRMLNode *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMRMLNode"))
  {
    if (ap.IsBound())
    {
      op->Copy(temp0);
    }
    else
    {
      op->vtkMRMLSegmentationStorageNode::Copy(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_GetNodeTagName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNodeTagName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetNodeTagName() :
      op->vtkMRMLSegmentationStorageNode::GetNodeTagName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_GetDefaultWriteFileExtension(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetDefaultWriteFileExtension");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetDefaultWriteFileExtension() :
      op->vtkMRMLSegmentationStorageNode::GetDefaultWriteFileExtension());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_CanReadInReferenceNode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CanReadInReferenceNode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  vtkMRMLNode *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMRMLNode"))
  {
    bool tempr = (ap.IsBound() ?
      op->CanReadInReferenceNode(temp0) :
      op->vtkMRMLSegmentationStorageNode::CanReadInReferenceNode(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_ResetSupportedWriteFileTypes(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ResetSupportedWriteFileTypes");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ResetSupportedWriteFileTypes();
    }
    else
    {
      op->vtkMRMLSegmentationStorageNode::ResetSupportedWriteFileTypes();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_SetCropToMinimumExtent(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCropToMinimumExtent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetCropToMinimumExtent(temp0);
    }
    else
    {
      op->vtkMRMLSegmentationStorageNode::SetCropToMinimumExtent(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_GetCropToMinimumExtent(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCropToMinimumExtent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetCropToMinimumExtent() :
      op->vtkMRMLSegmentationStorageNode::GetCropToMinimumExtent());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_CropToMinimumExtentOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CropToMinimumExtentOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->CropToMinimumExtentOn();
    }
    else
    {
      op->vtkMRMLSegmentationStorageNode::CropToMinimumExtentOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLSegmentationStorageNode_CropToMinimumExtentOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CropToMinimumExtentOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLSegmentationStorageNode *op = static_cast<vtkMRMLSegmentationStorageNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->CropToMinimumExtentOff();
    }
    else
    {
      op->vtkMRMLSegmentationStorageNode::CropToMinimumExtentOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkMRMLSegmentationStorageNode_Methods[] = {
  {"IsTypeOf", PyvtkMRMLSegmentationStorageNode_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkMRMLSegmentationStorageNode_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkMRMLSegmentationStorageNode_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkMRMLSegmentationStorageNode\nC++: static vtkMRMLSegmentationStorageNode *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkMRMLSegmentationStorageNode_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkMRMLSegmentationStorageNode\nC++: vtkMRMLSegmentationStorageNode *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkMRMLSegmentationStorageNode_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkMRMLSegmentationStorageNode_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"CreateNodeInstance", PyvtkMRMLSegmentationStorageNode_CreateNodeInstance, METH_VARARGS,
   "V.CreateNodeInstance() -> vtkMRMLNode\nC++: vtkMRMLNode *CreateNodeInstance() override;\n\nCreate instance of the default node. Like New only virtual.\n\note Subclasses should implement this method\n"},
  {"Copy", PyvtkMRMLSegmentationStorageNode_Copy, METH_VARARGS,
   "V.Copy(vtkMRMLNode)\nC++: void Copy(vtkMRMLNode *node) override;\n\nCopy the node's attributes to this object\n"},
  {"GetNodeTagName", PyvtkMRMLSegmentationStorageNode_GetNodeTagName, METH_VARARGS,
   "V.GetNodeTagName() -> string\nC++: const char *GetNodeTagName() override;\n\nGet node XML tag name (like Storage, Model)\n"},
  {"GetDefaultWriteFileExtension", PyvtkMRMLSegmentationStorageNode_GetDefaultWriteFileExtension, METH_VARARGS,
   "V.GetDefaultWriteFileExtension() -> string\nC++: const char *GetDefaultWriteFileExtension() override;\n\nReturn a default file extension for writing File write extension\nis determined dynamically from master representation type.\n"},
  {"CanReadInReferenceNode", PyvtkMRMLSegmentationStorageNode_CanReadInReferenceNode, METH_VARARGS,
   "V.CanReadInReferenceNode(vtkMRMLNode) -> bool\nC++: bool CanReadInReferenceNode(vtkMRMLNode *refNode) override;\n\nReturn true if the reference node can be read in\n"},
  {"ResetSupportedWriteFileTypes", PyvtkMRMLSegmentationStorageNode_ResetSupportedWriteFileTypes, METH_VARARGS,
   "V.ResetSupportedWriteFileTypes()\nC++: void ResetSupportedWriteFileTypes()\n\nReset supported write file types. Called when master\nrepresentation is changed\n"},
  {"SetCropToMinimumExtent", PyvtkMRMLSegmentationStorageNode_SetCropToMinimumExtent, METH_VARARGS,
   "V.SetCropToMinimumExtent(bool)\nC++: virtual void SetCropToMinimumExtent(bool _arg)\n\nControls if segmentation labelmap representation is written using\nminimum necessary extent or the extent of reference image. If\nfalse (default): the segmentation will be saved using the same\nextent as the reference image. If true: the segmentation will be\nsaved using the effective extent. This saves space (especially\nwhen saving the segmentation uncompressed), but makes voxel\ncoordinates of the segmentation different from voxel coordinates\nof the reference image, which may cause problems in software that\nassume voxel coordinate system of the reference image is the same\nas the segmentation's.\n"},
  {"GetCropToMinimumExtent", PyvtkMRMLSegmentationStorageNode_GetCropToMinimumExtent, METH_VARARGS,
   "V.GetCropToMinimumExtent() -> bool\nC++: virtual bool GetCropToMinimumExtent()\n\n"},
  {"CropToMinimumExtentOn", PyvtkMRMLSegmentationStorageNode_CropToMinimumExtentOn, METH_VARARGS,
   "V.CropToMinimumExtentOn()\nC++: virtual void CropToMinimumExtentOn()\n\n"},
  {"CropToMinimumExtentOff", PyvtkMRMLSegmentationStorageNode_CropToMinimumExtentOff, METH_VARARGS,
   "V.CropToMinimumExtentOff()\nC++: virtual void CropToMinimumExtentOff()\n\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkMRMLSegmentationStorageNode_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "MRMLCore.vtkMRMLSegmentationStorageNode", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkMRMLSegmentationStorageNode_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkMRMLSegmentationStorageNode_StaticNew()
{
  return vtkMRMLSegmentationStorageNode::New();
}

PyObject *PyvtkMRMLSegmentationStorageNode_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkMRMLSegmentationStorageNode_Type, PyvtkMRMLSegmentationStorageNode_Methods,
    "vtkMRMLSegmentationStorageNode",
 &PyvtkMRMLSegmentationStorageNode_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkMRMLStorageNode_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkMRMLSegmentationStorageNode(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkMRMLSegmentationStorageNode_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkMRMLSegmentationStorageNode", o) != 0)
  {
    Py_DECREF(o);
  }

}

