/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#include "vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory.h"
#include "vtkVersion.h"

// Include all of the classes we want to create overrides for.
#include "vtkMRMLAnnotationDisplayableManager.h"
#include "vtkMRMLAnnotationTextDisplayableManager.h"
#include "vtkMRMLAnnotationFiducialDisplayableManager.h"
#include "vtkMRMLAnnotationRulerDisplayableManager.h"
#include "vtkMRMLAnnotationBidimensionalDisplayableManager.h"
#include "vtkMRMLAnnotationROIDisplayableManager.h"


vtkStandardNewMacro(vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory)

// Now create the functions to create overrides with.

      VTK_CREATE_CREATE_FUNCTION(vtkMRMLAnnotationDisplayableManager)
      VTK_CREATE_CREATE_FUNCTION(vtkMRMLAnnotationTextDisplayableManager)
      VTK_CREATE_CREATE_FUNCTION(vtkMRMLAnnotationFiducialDisplayableManager)
      VTK_CREATE_CREATE_FUNCTION(vtkMRMLAnnotationRulerDisplayableManager)
      VTK_CREATE_CREATE_FUNCTION(vtkMRMLAnnotationBidimensionalDisplayableManager)
      VTK_CREATE_CREATE_FUNCTION(vtkMRMLAnnotationROIDisplayableManager)

vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory::vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory()
{

    this->RegisterOverride("vtkMRMLAnnotationDisplayableManager",
                           "vtkMRMLAnnotationDisplayableManager",
                           "Override for  module", 1,
                           vtkObjectFactoryCreatevtkMRMLAnnotationDisplayableManager);
    this->RegisterOverride("vtkMRMLAnnotationTextDisplayableManager",
                           "vtkMRMLAnnotationTextDisplayableManager",
                           "Override for  module", 1,
                           vtkObjectFactoryCreatevtkMRMLAnnotationTextDisplayableManager);
    this->RegisterOverride("vtkMRMLAnnotationFiducialDisplayableManager",
                           "vtkMRMLAnnotationFiducialDisplayableManager",
                           "Override for  module", 1,
                           vtkObjectFactoryCreatevtkMRMLAnnotationFiducialDisplayableManager);
    this->RegisterOverride("vtkMRMLAnnotationRulerDisplayableManager",
                           "vtkMRMLAnnotationRulerDisplayableManager",
                           "Override for  module", 1,
                           vtkObjectFactoryCreatevtkMRMLAnnotationRulerDisplayableManager);
    this->RegisterOverride("vtkMRMLAnnotationBidimensionalDisplayableManager",
                           "vtkMRMLAnnotationBidimensionalDisplayableManager",
                           "Override for  module", 1,
                           vtkObjectFactoryCreatevtkMRMLAnnotationBidimensionalDisplayableManager);
    this->RegisterOverride("vtkMRMLAnnotationROIDisplayableManager",
                           "vtkMRMLAnnotationROIDisplayableManager",
                           "Override for  module", 1,
                           vtkObjectFactoryCreatevtkMRMLAnnotationROIDisplayableManager);
}

const char * vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}

void vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

// Registration of object factories.
static unsigned int vtkSlicerAnnotationsModuleMRMLDisplayableManagerCount;

#ifdef vtkSlicerAnnotationsModuleMRMLDisplayableManager_AUTOINIT
# define VTK_SLICER_ANNOTATIONS_MODULE_MRMLDISPLAYABLEMANAGER_MODULEINIT_EXPORT
#else
# define VTK_SLICER_ANNOTATIONS_MODULE_MRMLDISPLAYABLEMANAGER_MODULEINIT_EXPORT VTK_SLICER_ANNOTATIONS_MODULE_MRMLDISPLAYABLEMANAGER_EXPORT
#endif

VTK_SLICER_ANNOTATIONS_MODULE_MRMLDISPLAYABLEMANAGER_MODULEINIT_EXPORT void vtkSlicerAnnotationsModuleMRMLDisplayableManager_AutoInit_Construct()
{
  if(++vtkSlicerAnnotationsModuleMRMLDisplayableManagerCount == 1)
    {
    
    vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory* factory = vtkSlicerAnnotationsModuleMRMLDisplayableManagerObjectFactory::New();
    if (factory)
      {
      // vtkObjectFactory keeps a reference to the "factory",
      vtkObjectFactory::RegisterFactory(factory);
      factory->Delete();
      }
    }
}

VTK_SLICER_ANNOTATIONS_MODULE_MRMLDISPLAYABLEMANAGER_MODULEINIT_EXPORT void vtkSlicerAnnotationsModuleMRMLDisplayableManager_AutoInit_Destruct()
{
  if(--vtkSlicerAnnotationsModuleMRMLDisplayableManagerCount == 0)
    {
    // Do not call vtkObjectFactory::UnRegisterFactory because
    // vtkObjectFactory.cxx statically unregisters all factories.
    }
}
