// python wrapper for vtkMRMLMarkupsCurveNode
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkMRMLMarkupsCurveNode.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkMRMLMarkupsCurveNode(PyObject *dict); }
extern "C" { PyObject *PyvtkMRMLMarkupsCurveNode_ClassNew(); }

#ifndef DECLARED_PyvtkMRMLMarkupsNode_ClassNew
extern "C" { PyObject *PyvtkMRMLMarkupsNode_ClassNew(); }
#define DECLARED_PyvtkMRMLMarkupsNode_ClassNew
#endif

static const char *PyvtkMRMLMarkupsCurveNode_Doc =
  "vtkMRMLMarkupsCurveNode - MRML node to represent a curve markup\n\n"
  "Superclass: vtkMRMLMarkupsNode\n\n"
  "Curve Markups nodes contain N control points. Visualization\n"
  "parameters are set in the vtkMRMLMarkupsDisplayNode class.\n\n"
  "Markups is intended to be used for manual marking/editing of point\n"
  "positions.\n\n"
  "Coordinate systems used:\n"
  "- Local: Current node's coordinate system where the position of the\n"
  "  control and curve points are defined. Local coordinates can be\n"
  "  converted to world by concatenating all parent transforms on the\n"
  "  current node.\n"
  "- Surface: Model node's coordinate system where the polydata used for\n"
  "ShortestDistanceOnSurface pathfinding is defined. Surface coordinates\n"
  "can be converted to world by concatenating all parent transforms on\n"
  "  the surface node.\n"
  "- World: Patient coordinate system (RAS)\n\n"
  "Markups measurement pipeline:\n\n"
  "+------------------------------------------vtkMarkupsCurveNode--------\n"
  "---------------------------------------+ |  +-vtkMRMLMarkupsNode-+   \n"
  "                                                         === :\n"
  "Display pipeline | |  |                    |       \n"
  "+-vtkCurveGenerator-+                                                \n"
  "      | |  |   CurveInputPoly=============                   | :\n"
  "Generate interpolated curve from the control points | |  |  \n"
  "Measurements--------+     +---------\342\225\221---------+                    \n"
  "                                  | |  |                    |  |     \n"
  "         \342\225\221                                                         \n"
  "       | |  +--------------------+  |               \342\225\221              \n"
  "                                                  | |                \n"
  "        ++-vtkCurveMeasurementsCalculator-+                          \n"
  "                     | |                         |                   \n"
  "             | : Add measurements as data arrays to the curve | |    \n"
  "                    +----------------\342\225\221----------------+   poly data\n"
  "                                   | |                               \n"
  "          \342\225\221                                                        \n"
  "        | |                                          \342\225\221             \n"
  "                                                   | |               \n"
  "         +---vtkTransformPolyDataFilter----+                         \n"
  "                      | |                         | \n"
  "(CurvePolyToWorldTransformer)  |                                     \n"
  "          | |                        \n"
  "+----------------\342\225\221----------------+                                \n"
  "               | |                                          \342\225\221      \n"
  "                                                          |\n"
  "+------------------------------------------\342\225\221------------------------\n"
  "-----------------------------------------+\n"
  "                                           \342\225\221\n"
  "                        \n"
  "+-----------------\342\225\221-------vtkSlicerCurveRepresentation3D------------\n"
  "----------+\n"
  "                         |                 \342\225\221                       \n"
  "                                   |\n"
  "                         |                 \342\225\221(vtkCleaner in between)\n"
  "                                   |\n"
  "                         |        +--vtkTubeFilter--+                \n"
  "                                 |\n"
  "                         |        |                 =========>\n"
  "vtkPolyDataMapper => vtkActor           |\n"
  "                         |        +-----------------+                \n"
  "                                 |\n"
  "                        \n"
  "+---------------------------------------------------------------------\n"
  "--------+\n\n"
  "\\ingroup Slicer_QtModules_Markups\n\n";


static PyObject *
PyvtkMRMLMarkupsCurveNode_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkMRMLMarkupsCurveNode::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkMRMLMarkupsCurveNode::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkMRMLMarkupsCurveNode *tempr = vtkMRMLMarkupsCurveNode::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMRMLMarkupsCurveNode *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkMRMLMarkupsCurveNode::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkMRMLMarkupsCurveNode::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkMRMLMarkupsCurveNode::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetIcon(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetIcon");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetIcon() :
      op->vtkMRMLMarkupsCurveNode::GetIcon());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_CreateNodeInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateNodeInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMRMLNode *tempr = (ap.IsBound() ?
      op->CreateNodeInstance() :
      op->vtkMRMLMarkupsCurveNode::CreateNodeInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetNodeTagName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNodeTagName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetNodeTagName() :
      op->vtkMRMLMarkupsCurveNode::GetNodeTagName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_CopyContent(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CopyContent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  vtkMRMLNode *temp0 = nullptr;
  bool temp1 = true;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1, 2) &&
      ap.GetVTKObject(temp0, "vtkMRMLNode") &&
      (ap.NoArgsLeft() || ap.GetValue(temp1)))
  {
    if (ap.IsBound())
    {
      op->CopyContent(temp0, temp1);
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::CopyContent(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_HasCopyContent(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "HasCopyContent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->HasCopyContent() :
      op->vtkMRMLMarkupsCurveNode::HasCopyContent());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurvePointsWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurvePointsWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkPoints *tempr = (ap.IsBound() ?
      op->GetCurvePointsWorld() :
      op->vtkMRMLMarkupsCurveNode::GetCurvePointsWorld());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurveLengthWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurveLengthWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0 = 0;
  int temp1 = -1;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0, 2) &&
      (ap.NoArgsLeft() || ap.GetValue(temp0)) &&
      (ap.NoArgsLeft() || ap.GetValue(temp1)))
  {
    double tempr = (ap.IsBound() ?
      op->GetCurveLengthWorld(temp0, temp1) :
      op->vtkMRMLMarkupsCurveNode::GetCurveLengthWorld(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurveLength(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetCurveLength");

  vtkPoints *temp0 = nullptr;
  bool temp1 = false;
  int temp2 = 0;
  int temp3 = -1;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(2, 4) &&
      ap.GetVTKObject(temp0, "vtkPoints") &&
      ap.GetValue(temp1) &&
      (ap.NoArgsLeft() || ap.GetValue(temp2)) &&
      (ap.NoArgsLeft() || ap.GetValue(temp3)))
  {
    double tempr = vtkMRMLMarkupsCurveNode::GetCurveLength(temp0, temp1, temp2, temp3);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurveLengthBetweenStartEndPointsWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurveLengthBetweenStartEndPointsWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  int temp1;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1))
  {
    double tempr = (ap.IsBound() ?
      op->GetCurveLengthBetweenStartEndPointsWorld(temp0, temp1) :
      op->vtkMRMLMarkupsCurveNode::GetCurveLengthBetweenStartEndPointsWorld(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetControlPointLabels(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetControlPointLabels");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  vtkStringArray *temp0 = nullptr;
  vtkPoints *temp1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkStringArray") &&
      ap.GetVTKObject(temp1, "vtkPoints"))
  {
    bool tempr = (ap.IsBound() ?
      op->SetControlPointLabels(temp0, temp1) :
      op->vtkMRMLMarkupsCurveNode::SetControlPointLabels(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_ResampleCurveSurface(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ResampleCurveSurface");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  double temp0;
  vtkMRMLModelNode *temp1 = nullptr;
  double temp2 = .25;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2, 3) &&
      ap.GetValue(temp0) &&
      ap.GetVTKObject(temp1, "vtkMRMLModelNode") &&
      (ap.NoArgsLeft() || ap.GetValue(temp2)))
  {
    bool tempr = (ap.IsBound() ?
      op->ResampleCurveSurface(temp0, temp1, temp2) :
      op->vtkMRMLMarkupsCurveNode::ResampleCurveSurface(temp0, temp1, temp2));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_ConstrainPointsToSurface(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "ConstrainPointsToSurface");

  vtkPoints *temp0 = nullptr;
  vtkPoints *temp1 = nullptr;
  vtkPolyData *temp2 = nullptr;
  vtkPoints *temp3 = nullptr;
  double temp4 = .25;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(4, 5) &&
      ap.GetVTKObject(temp0, "vtkPoints") &&
      ap.GetVTKObject(temp1, "vtkPoints") &&
      ap.GetVTKObject(temp2, "vtkPolyData") &&
      ap.GetVTKObject(temp3, "vtkPoints") &&
      (ap.NoArgsLeft() || ap.GetValue(temp4)))
  {
    bool tempr = vtkMRMLMarkupsCurveNode::ConstrainPointsToSurface(temp0, temp1, temp2, temp3, temp4);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_ResampleCurveWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ResampleCurveWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->ResampleCurveWorld(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::ResampleCurveWorld(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_ResamplePoints(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "ResamplePoints");

  vtkPoints *temp0 = nullptr;
  vtkPoints *temp1 = nullptr;
  double temp2;
  bool temp3 = false;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(4) &&
      ap.GetVTKObject(temp0, "vtkPoints") &&
      ap.GetVTKObject(temp1, "vtkPoints") &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3))
  {
    bool tempr = vtkMRMLMarkupsCurveNode::ResamplePoints(temp0, temp1, temp2, temp3);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetSampledCurvePointsBetweenStartEndPointsWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSampledCurvePointsBetweenStartEndPointsWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  vtkPoints *temp0 = nullptr;
  double temp1;
  int temp2;
  int temp3;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(4) &&
      ap.GetVTKObject(temp0, "vtkPoints") &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3))
  {
    bool tempr = (ap.IsBound() ?
      op->GetSampledCurvePointsBetweenStartEndPointsWorld(temp0, temp1, temp2, temp3) :
      op->vtkMRMLMarkupsCurveNode::GetSampledCurvePointsBetweenStartEndPointsWorld(temp0, temp1, temp2, temp3));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetClosestCurvePointIndexToPositionWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetClosestCurvePointIndexToPositionWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    int tempr = (ap.IsBound() ?
      op->GetClosestCurvePointIndexToPositionWorld(temp0) :
      op->vtkMRMLMarkupsCurveNode::GetClosestCurvePointIndexToPositionWorld(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetClosestPointPositionAlongCurveWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetClosestPointPositionAlongCurveWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  const size_t size1 = 3;
  double temp1[3];
  double save1[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetArray(temp0, size0) &&
      ap.GetArray(temp1, size1))
  {
    vtkPythonArgs::Save(temp1, save1, size1);

    int tempr = (ap.IsBound() ?
      op->GetClosestPointPositionAlongCurveWorld(temp0, temp1) :
      op->vtkMRMLMarkupsCurveNode::GetClosestPointPositionAlongCurveWorld(temp0, temp1));

    if (vtkPythonArgs::HasChanged(temp1, save1, size1) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(1, temp1, size1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetFarthestCurvePointIndexToPositionWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFarthestCurvePointIndexToPositionWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    int tempr = (ap.IsBound() ?
      op->GetFarthestCurvePointIndexToPositionWorld(temp0) :
      op->vtkMRMLMarkupsCurveNode::GetFarthestCurvePointIndexToPositionWorld(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurvePointIndexFromControlPointIndex(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurvePointIndexFromControlPointIndex");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetCurvePointIndexFromControlPointIndex(temp0) :
      op->vtkMRMLMarkupsCurveNode::GetCurvePointIndexFromControlPointIndex(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetPositionAndClosestPointIndexAlongCurve(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetPositionAndClosestPointIndexAlongCurve");

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  int temp1;
  int temp2;
  double temp3;
  vtkPoints *temp4 = nullptr;
  bool temp5 = false;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(6) &&
      ap.GetArray(temp0, size0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3) &&
      ap.GetVTKObject(temp4, "vtkPoints") &&
      ap.GetValue(temp5))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    bool tempr = vtkMRMLMarkupsCurveNode::GetPositionAndClosestPointIndexAlongCurve(temp0, temp1, temp2, temp3, temp4, temp5);

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      ap.SetArgValue(1, temp1);
    }
    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurvePointIndexAlongCurveWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurvePointIndexAlongCurveWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  double temp1;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1))
  {
    int tempr = (ap.IsBound() ?
      op->GetCurvePointIndexAlongCurveWorld(temp0, temp1) :
      op->vtkMRMLMarkupsCurveNode::GetCurvePointIndexAlongCurveWorld(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetPositionAlongCurveWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetPositionAlongCurveWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  int temp1;
  double temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetArray(temp0, size0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    bool tempr = (ap.IsBound() ?
      op->GetPositionAlongCurveWorld(temp0, temp1, temp2) :
      op->vtkMRMLMarkupsCurveNode::GetPositionAlongCurveWorld(temp0, temp1, temp2));

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurveDirectionAtPointIndexWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurveDirectionAtPointIndexWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  const size_t size1 = 3;
  double temp1[3];
  double save1[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetArray(temp1, size1))
  {
    vtkPythonArgs::Save(temp1, save1, size1);

    bool tempr = (ap.IsBound() ?
      op->GetCurveDirectionAtPointIndexWorld(temp0, temp1) :
      op->vtkMRMLMarkupsCurveNode::GetCurveDirectionAtPointIndexWorld(temp0, temp1));

    if (vtkPythonArgs::HasChanged(temp1, save1, size1) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(1, temp1, size1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurvePointToWorldTransformAtPointIndex(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurvePointToWorldTransformAtPointIndex");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  vtkMatrix4x4 *temp1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetVTKObject(temp1, "vtkMatrix4x4"))
  {
    bool tempr = (ap.IsBound() ?
      op->GetCurvePointToWorldTransformAtPointIndex(temp0, temp1) :
      op->vtkMRMLMarkupsCurveNode::GetCurvePointToWorldTransformAtPointIndex(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetPointsOnPlaneWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetPointsOnPlaneWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  vtkPlane *temp0 = nullptr;
  vtkPoints *temp1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkPlane") &&
      ap.GetVTKObject(temp1, "vtkPoints"))
  {
    bool tempr = (ap.IsBound() ?
      op->GetPointsOnPlaneWorld(temp0, temp1) :
      op->vtkMRMLMarkupsCurveNode::GetPointsOnPlaneWorld(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurveType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurveType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetCurveType() :
      op->vtkMRMLMarkupsCurveNode::GetCurveType());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetCurveType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCurveType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetCurveType(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetCurveType(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurveTypeAsString(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurveTypeAsString");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetCurveTypeAsString(temp0) :
      op->vtkMRMLMarkupsCurveNode::GetCurveTypeAsString(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetCurveTypeFromString(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCurveTypeFromString");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetCurveTypeFromString(temp0) :
      op->vtkMRMLMarkupsCurveNode::GetCurveTypeFromString(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetCurveTypeToLinear(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCurveTypeToLinear");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->SetCurveTypeToLinear();
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetCurveTypeToLinear();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetCurveTypeToCardinalSpline(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCurveTypeToCardinalSpline");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->SetCurveTypeToCardinalSpline();
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetCurveTypeToCardinalSpline();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetCurveTypeToKochanekSpline(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCurveTypeToKochanekSpline");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->SetCurveTypeToKochanekSpline();
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetCurveTypeToKochanekSpline();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetCurveTypeToPolynomial(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCurveTypeToPolynomial");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->SetCurveTypeToPolynomial();
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetCurveTypeToPolynomial();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetCurveTypeToShortestDistanceOnSurface(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCurveTypeToShortestDistanceOnSurface");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  vtkMRMLModelNode *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0, 1) &&
      (ap.NoArgsLeft() || ap.GetVTKObject(temp0, "vtkMRMLModelNode")))
  {
    if (ap.IsBound())
    {
      op->SetCurveTypeToShortestDistanceOnSurface(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetCurveTypeToShortestDistanceOnSurface(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetShortestDistanceSurfaceNodeReferenceRole(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetShortestDistanceSurfaceNodeReferenceRole");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetShortestDistanceSurfaceNodeReferenceRole() :
      op->vtkMRMLMarkupsCurveNode::GetShortestDistanceSurfaceNodeReferenceRole());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetShortestDistanceSurfaceNodeReferenceMRMLAttributeName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetShortestDistanceSurfaceNodeReferenceMRMLAttributeName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetShortestDistanceSurfaceNodeReferenceMRMLAttributeName() :
      op->vtkMRMLMarkupsCurveNode::GetShortestDistanceSurfaceNodeReferenceMRMLAttributeName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetAndObserveShortestDistanceSurfaceNode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAndObserveShortestDistanceSurfaceNode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  vtkMRMLModelNode *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMRMLModelNode"))
  {
    if (ap.IsBound())
    {
      op->SetAndObserveShortestDistanceSurfaceNode(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetAndObserveShortestDistanceSurfaceNode(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetShortestDistanceSurfaceNode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetShortestDistanceSurfaceNode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMRMLModelNode *tempr = (ap.IsBound() ?
      op->GetShortestDistanceSurfaceNode() :
      op->vtkMRMLMarkupsCurveNode::GetShortestDistanceSurfaceNode());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetSurfaceCostFunctionType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSurfaceCostFunctionType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetSurfaceCostFunctionType() :
      op->vtkMRMLMarkupsCurveNode::GetSurfaceCostFunctionType());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetSurfaceCostFunctionType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSurfaceCostFunctionType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetSurfaceCostFunctionType(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetSurfaceCostFunctionType(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetSurfaceCostFunctionTypeAsString(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetSurfaceCostFunctionTypeAsString");

  int temp0;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    const char *tempr = vtkMRMLMarkupsCurveNode::GetSurfaceCostFunctionTypeAsString(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetSurfaceCostFunctionTypeFromString(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetSurfaceCostFunctionTypeFromString");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkMRMLMarkupsCurveNode::GetSurfaceCostFunctionTypeFromString(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetSurfaceDistanceWeightingFunction(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSurfaceDistanceWeightingFunction");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetSurfaceDistanceWeightingFunction() :
      op->vtkMRMLMarkupsCurveNode::GetSurfaceDistanceWeightingFunction());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetSurfaceDistanceWeightingFunction(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSurfaceDistanceWeightingFunction");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetSurfaceDistanceWeightingFunction(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetSurfaceDistanceWeightingFunction(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_GetNumberOfPointsPerInterpolatingSegment(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfPointsPerInterpolatingSegment");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfPointsPerInterpolatingSegment() :
      op->vtkMRMLMarkupsCurveNode::GetNumberOfPointsPerInterpolatingSegment());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_SetNumberOfPointsPerInterpolatingSegment(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetNumberOfPointsPerInterpolatingSegment");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetNumberOfPointsPerInterpolatingSegment(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::SetNumberOfPointsPerInterpolatingSegment(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsCurveNode_UpdateAssignedAttribute(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UpdateAssignedAttribute");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsCurveNode *op = static_cast<vtkMRMLMarkupsCurveNode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UpdateAssignedAttribute();
    }
    else
    {
      op->vtkMRMLMarkupsCurveNode::UpdateAssignedAttribute();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkMRMLMarkupsCurveNode_Methods[] = {
  {"IsTypeOf", PyvtkMRMLMarkupsCurveNode_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkMRMLMarkupsCurveNode_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkMRMLMarkupsCurveNode_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkMRMLMarkupsCurveNode\nC++: static vtkMRMLMarkupsCurveNode *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkMRMLMarkupsCurveNode_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkMRMLMarkupsCurveNode\nC++: vtkMRMLMarkupsCurveNode *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkMRMLMarkupsCurveNode_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkMRMLMarkupsCurveNode_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetIcon", PyvtkMRMLMarkupsCurveNode_GetIcon, METH_VARARGS,
   "V.GetIcon() -> string\nC++: const char *GetIcon() override;\n\n"},
  {"CreateNodeInstance", PyvtkMRMLMarkupsCurveNode_CreateNodeInstance, METH_VARARGS,
   "V.CreateNodeInstance() -> vtkMRMLNode\nC++: vtkMRMLNode *CreateNodeInstance() override;\n\nMRMLNode methods\n"},
  {"GetNodeTagName", PyvtkMRMLMarkupsCurveNode_GetNodeTagName, METH_VARARGS,
   "V.GetNodeTagName() -> string\nC++: const char *GetNodeTagName() override;\n\nGet node XML tag name (like Volume, Model)\n"},
  {"CopyContent", PyvtkMRMLMarkupsCurveNode_CopyContent, METH_VARARGS,
   "V.CopyContent(vtkMRMLNode, bool)\nC++: void CopyContent(vtkMRMLNode *node, bool deepCopy=true)\n    override;\n\nCopy node content (excludes basic data, such as name and node\nreferences).\n\\sa vtkMRMLNode::CopyContent\n"},
  {"HasCopyContent", PyvtkMRMLMarkupsCurveNode_HasCopyContent, METH_VARARGS,
   "V.HasCopyContent() -> bool\nC++: bool HasCopyContent() override;\n\nReturns true if the class supports deep and shallow copying node\n    content.\n"},
  {"GetCurvePointsWorld", PyvtkMRMLMarkupsCurveNode_GetCurvePointsWorld, METH_VARARGS,
   "V.GetCurvePointsWorld() -> vtkPoints\nC++: vtkPoints *GetCurvePointsWorld()\n\nGet curve points positions in world coordinate system.\n"},
  {"GetCurveLengthWorld", PyvtkMRMLMarkupsCurveNode_GetCurveLengthWorld, METH_VARARGS,
   "V.GetCurveLengthWorld(int, int) -> float\nC++: double GetCurveLengthWorld(vtkIdType startCurvePointIndex=0,\n    vtkIdType numberOfCurvePoints=-1)\n\nGet length of the curve or a section of the curve.\n\\param startCurvePointIndex length computation starts from this\n    curve point index\n\\param numberOfCurvePoints if specified then distances up to the\n    first n points are computed.\n  If <0 then all the points are used.\n\\return sum of distances between the curve points, returns 0 in\n    case of an error\n"},
  {"GetCurveLength", PyvtkMRMLMarkupsCurveNode_GetCurveLength, METH_VARARGS,
   "V.GetCurveLength(vtkPoints, bool, int, int) -> float\nC++: static double GetCurveLength(vtkPoints *curvePoints,\n    bool closedCurve, vtkIdType startCurvePointIndex=0,\n    vtkIdType numberOfCurvePoints=-1)\n\nUtility function to get curve length from a point list.\n\\sa GetCurveLengthWorld\n"},
  {"GetCurveLengthBetweenStartEndPointsWorld", PyvtkMRMLMarkupsCurveNode_GetCurveLengthBetweenStartEndPointsWorld, METH_VARARGS,
   "V.GetCurveLengthBetweenStartEndPointsWorld(int, int) -> float\nC++: double GetCurveLengthBetweenStartEndPointsWorld(\n    vtkIdType startCurvePointIndex, vtkIdType endCurvePointIndex)\n\nGet length of a section of the curve between startPointIndex and\nendPointIndex. If endPointIndex < startPointIndex then length\noutside of the section is computed.\n\\param startCurvePointIndex length computation starts from this\n    curve point index\n\\param endCurvePointIndex length computation starts from this\n    curve point index\n\\return sum of distances between the curve points, returns 0 in\n    case of an error\n"},
  {"SetControlPointLabels", PyvtkMRMLMarkupsCurveNode_SetControlPointLabels, METH_VARARGS,
   "V.SetControlPointLabels(vtkStringArray, vtkPoints) -> bool\nC++: bool SetControlPointLabels(vtkStringArray *labels,\n    vtkPoints *points)\n\nProvides access to protected\nvtkMRMLMarkupsNode::SetControlPointLabelsWorld\n"},
  {"ResampleCurveSurface", PyvtkMRMLMarkupsCurveNode_ResampleCurveSurface, METH_VARARGS,
   "V.ResampleCurveSurface(float, vtkMRMLModelNode, float) -> bool\nC++: bool ResampleCurveSurface(double controlPointDistance,\n    vtkMRMLModelNode *node, double maximumSearchRadius=.25)\n\nResample a curve with points constrained to surface Projection to\nsurface is constrained by maximumSearchRadius, specified as a\npercentage of the model's bounding box diagonal in world\ncoordinate system. Valid in the range between 0 and 1.\nmaximumSearchRadius is valid in the range between 0 and 1.\nreturns true if successful, false in case of error\n"},
  {"ConstrainPointsToSurface", PyvtkMRMLMarkupsCurveNode_ConstrainPointsToSurface, METH_VARARGS,
   "V.ConstrainPointsToSurface(vtkPoints, vtkPoints, vtkPolyData,\n    vtkPoints, float) -> bool\nC++: static bool ConstrainPointsToSurface(\n    vtkPoints *originalPoints, vtkPoints *normalVectors,\n    vtkPolyData *surfacePolydata, vtkPoints *surfacePoints,\n    double maximumSearchRadius=.25)\n\nConstrain points to a specified model surface Projection to\nsurface is constrained by maximumSearchRadius, specified as a\npercentage of the model's bounding box diagonal in world\ncoordinate system. maximumSearchRadius is valid in the range\nbetween 0 and 1. returns true if successful, false in case of\nerror\n"},
  {"ResampleCurveWorld", PyvtkMRMLMarkupsCurveNode_ResampleCurveWorld, METH_VARARGS,
   "V.ResampleCurveWorld(float)\nC++: void ResampleCurveWorld(double controlPointDistance)\n\n"},
  {"ResamplePoints", PyvtkMRMLMarkupsCurveNode_ResamplePoints, METH_VARARGS,
   "V.ResamplePoints(vtkPoints, vtkPoints, float, bool) -> bool\nC++: static bool ResamplePoints(vtkPoints *originalPoints,\n    vtkPoints *interpolatedPoints, double samplingDistance,\n    bool closedCurve)\n\n"},
  {"GetSampledCurvePointsBetweenStartEndPointsWorld", PyvtkMRMLMarkupsCurveNode_GetSampledCurvePointsBetweenStartEndPointsWorld, METH_VARARGS,
   "V.GetSampledCurvePointsBetweenStartEndPointsWorld(vtkPoints,\n    float, int, int) -> bool\nC++: bool GetSampledCurvePointsBetweenStartEndPointsWorld(\n    vtkPoints *sampledPoints, double samplingDistance,\n    vtkIdType startCurvePointIndex, vtkIdType endCurvePointIndex)\n\nSamples points along the curve at equal distances. If\nendPointIndex < startPointIndex then after the last point, the\ncurve is assumed to continue at the first point.\n"},
  {"GetClosestCurvePointIndexToPositionWorld", PyvtkMRMLMarkupsCurveNode_GetClosestCurvePointIndexToPositionWorld, METH_VARARGS,
   "V.GetClosestCurvePointIndexToPositionWorld((float, float, float))\n    -> int\nC++: vtkIdType GetClosestCurvePointIndexToPositionWorld(\n    const double posWorld[3])\n\nGet the index of the closest curve point to the world coordinates\n"},
  {"GetClosestPointPositionAlongCurveWorld", PyvtkMRMLMarkupsCurveNode_GetClosestPointPositionAlongCurveWorld, METH_VARARGS,
   "V.GetClosestPointPositionAlongCurveWorld((float, float, float),\n    [float, float, float]) -> int\nC++: vtkIdType GetClosestPointPositionAlongCurveWorld(\n    const double posWorld[3], double closestPosWorld[3])\n\nGet position of the closest point along the curve in world\ncoordinates. The found position may be between two curve points.\nReturns index of the found line segment. -1 if failed.\n\\param posWorld: input position\n\\param closestPosWorld: output found closest position\n"},
  {"GetFarthestCurvePointIndexToPositionWorld", PyvtkMRMLMarkupsCurveNode_GetFarthestCurvePointIndexToPositionWorld, METH_VARARGS,
   "V.GetFarthestCurvePointIndexToPositionWorld((float, float, float))\n     -> int\nC++: vtkIdType GetFarthestCurvePointIndexToPositionWorld(\n    const double posWorld[3])\n\nGet index of the farthest curve point from the specified\nreference point. Distance is Euclidean distance, not distance\nalong the curve.\n\\param posWorld Reference point position in world coordinate\n    system\n\\return index of the farthest curve point from refPoint, -1 in\n    case of error\n"},
  {"GetCurvePointIndexFromControlPointIndex", PyvtkMRMLMarkupsCurveNode_GetCurvePointIndexFromControlPointIndex, METH_VARARGS,
   "V.GetCurvePointIndexFromControlPointIndex(int) -> int\nC++: vtkIdType GetCurvePointIndexFromControlPointIndex(\n    int controlPointIndex)\n\nGet curve point index corresponding to a control point. It is\nuseful for calling methods that require curve point index as\ninput.\n"},
  {"GetPositionAndClosestPointIndexAlongCurve", PyvtkMRMLMarkupsCurveNode_GetPositionAndClosestPointIndexAlongCurve, METH_VARARGS,
   "V.GetPositionAndClosestPointIndexAlongCurve([float, float, float],\n     int, int, float, vtkPoints, bool) -> bool\nC++: static bool GetPositionAndClosestPointIndexAlongCurve(\n    double foundCurvePosition[3],\n    vtkIdType &foundClosestPointIndex,\n    vtkIdType startCurvePointId, double distanceFromStartPoint,\n    vtkPoints *curvePoints, bool closedCurve)\n\nGet point position along curve. Position is found along the curve\nand not snapped to closest curve point.\n"},
  {"GetCurvePointIndexAlongCurveWorld", PyvtkMRMLMarkupsCurveNode_GetCurvePointIndexAlongCurveWorld, METH_VARARGS,
   "V.GetCurvePointIndexAlongCurveWorld(int, float) -> int\nC++: vtkIdType GetCurvePointIndexAlongCurveWorld(\n    vtkIdType startCurvePointId, double distanceFromStartPoint)\n\nGet position of a curve point along the curve relative to the\nspecified start point index.\n\\param startCurvePointId index of the curve point to start the\n    distance measurement from\n\\param distanceFromStartPoint distance from the start point\n\\return found point index, -1 in case of an error\n"},
  {"GetPositionAlongCurveWorld", PyvtkMRMLMarkupsCurveNode_GetPositionAlongCurveWorld, METH_VARARGS,
   "V.GetPositionAlongCurveWorld([float, float, float], int, float)\n    -> bool\nC++: bool GetPositionAlongCurveWorld(double foundCurvePosition[3],\n     vtkIdType startCurvePointId, double distanceFromStartPoint)\n\nGet position of a point along the curve relative to the specified\nstart point index. The returned position can be between curve\npoints (to match the requested distance as accurately as\npossible).\n\\param startCurvePointId index of the curve point to start the\n    distance measurement from\n\\param distanceFromStartPoint distance from the start point\n\\return true if a point found exactly at the requested distance\n"},
  {"GetCurveDirectionAtPointIndexWorld", PyvtkMRMLMarkupsCurveNode_GetCurveDirectionAtPointIndexWorld, METH_VARARGS,
   "V.GetCurveDirectionAtPointIndexWorld(int, [float, float, float])\n    -> bool\nC++: bool GetCurveDirectionAtPointIndexWorld(\n    vtkIdType curvePointIndex, double directionVectorWorld[3])\n\nGet direction vector at specified curve point index, in World\ncoordinate system.\n\\return true on success.\n"},
  {"GetCurvePointToWorldTransformAtPointIndex", PyvtkMRMLMarkupsCurveNode_GetCurvePointToWorldTransformAtPointIndex, METH_VARARGS,
   "V.GetCurvePointToWorldTransformAtPointIndex(int, vtkMatrix4x4)\n    -> bool\nC++: bool GetCurvePointToWorldTransformAtPointIndex(\n    vtkIdType curvePointIndex, vtkMatrix4x4 *curvePointToWorld)\n\nGet transformation from CurvePoint to World coordinate system at\nthe specified curve point index. CurvePoint coordinate system:\n- Origin: position of the curve point.\n- X axis: curve normal direction.\n- Y axis: binormal direction (tangent x normal).\n- Z axis: curve tangent direction.\n\\return true on success.\n"},
  {"GetPointsOnPlaneWorld", PyvtkMRMLMarkupsCurveNode_GetPointsOnPlaneWorld, METH_VARARGS,
   "V.GetPointsOnPlaneWorld(vtkPlane, vtkPoints) -> bool\nC++: bool GetPointsOnPlaneWorld(vtkPlane *plane,\n    vtkPoints *intersectionPoints)\n\n"},
  {"GetCurveType", PyvtkMRMLMarkupsCurveNode_GetCurveType, METH_VARARGS,
   "V.GetCurveType() -> int\nC++: int GetCurveType()\n\nType of curve to generate\n"},
  {"SetCurveType", PyvtkMRMLMarkupsCurveNode_SetCurveType, METH_VARARGS,
   "V.SetCurveType(int)\nC++: void SetCurveType(int type)\n\n"},
  {"GetCurveTypeAsString", PyvtkMRMLMarkupsCurveNode_GetCurveTypeAsString, METH_VARARGS,
   "V.GetCurveTypeAsString(int) -> string\nC++: const char *GetCurveTypeAsString(int id)\n\n"},
  {"GetCurveTypeFromString", PyvtkMRMLMarkupsCurveNode_GetCurveTypeFromString, METH_VARARGS,
   "V.GetCurveTypeFromString(string) -> int\nC++: int GetCurveTypeFromString(const char *name)\n\n"},
  {"SetCurveTypeToLinear", PyvtkMRMLMarkupsCurveNode_SetCurveTypeToLinear, METH_VARARGS,
   "V.SetCurveTypeToLinear()\nC++: void SetCurveTypeToLinear()\n\n"},
  {"SetCurveTypeToCardinalSpline", PyvtkMRMLMarkupsCurveNode_SetCurveTypeToCardinalSpline, METH_VARARGS,
   "V.SetCurveTypeToCardinalSpline()\nC++: void SetCurveTypeToCardinalSpline()\n\n"},
  {"SetCurveTypeToKochanekSpline", PyvtkMRMLMarkupsCurveNode_SetCurveTypeToKochanekSpline, METH_VARARGS,
   "V.SetCurveTypeToKochanekSpline()\nC++: void SetCurveTypeToKochanekSpline()\n\n"},
  {"SetCurveTypeToPolynomial", PyvtkMRMLMarkupsCurveNode_SetCurveTypeToPolynomial, METH_VARARGS,
   "V.SetCurveTypeToPolynomial()\nC++: void SetCurveTypeToPolynomial()\n\n"},
  {"SetCurveTypeToShortestDistanceOnSurface", PyvtkMRMLMarkupsCurveNode_SetCurveTypeToShortestDistanceOnSurface, METH_VARARGS,
   "V.SetCurveTypeToShortestDistanceOnSurface(vtkMRMLModelNode)\nC++: void SetCurveTypeToShortestDistanceOnSurface(\n    vtkMRMLModelNode *modelNode=nullptr)\n\n"},
  {"GetShortestDistanceSurfaceNodeReferenceRole", PyvtkMRMLMarkupsCurveNode_GetShortestDistanceSurfaceNodeReferenceRole, METH_VARARGS,
   "V.GetShortestDistanceSurfaceNodeReferenceRole() -> string\nC++: const char *GetShortestDistanceSurfaceNodeReferenceRole()\n\nNode reference role for the surface that is used in the shortest\nsurface distance curve type\n"},
  {"GetShortestDistanceSurfaceNodeReferenceMRMLAttributeName", PyvtkMRMLMarkupsCurveNode_GetShortestDistanceSurfaceNodeReferenceMRMLAttributeName, METH_VARARGS,
   "V.GetShortestDistanceSurfaceNodeReferenceMRMLAttributeName()\n    -> string\nC++: const char *GetShortestDistanceSurfaceNodeReferenceMRMLAttributeName(\n    )\n\n"},
  {"SetAndObserveShortestDistanceSurfaceNode", PyvtkMRMLMarkupsCurveNode_SetAndObserveShortestDistanceSurfaceNode, METH_VARARGS,
   "V.SetAndObserveShortestDistanceSurfaceNode(vtkMRMLModelNode)\nC++: void SetAndObserveShortestDistanceSurfaceNode(\n    vtkMRMLModelNode *modelNode)\n\nThe model node that is used as the surface mesh for finding the\nshortest distance path on the surface mesh. Used by the\nShortestDistanceOnSurface curve type.\n"},
  {"GetShortestDistanceSurfaceNode", PyvtkMRMLMarkupsCurveNode_GetShortestDistanceSurfaceNode, METH_VARARGS,
   "V.GetShortestDistanceSurfaceNode() -> vtkMRMLModelNode\nC++: vtkMRMLModelNode *GetShortestDistanceSurfaceNode()\n\n"},
  {"GetSurfaceCostFunctionType", PyvtkMRMLMarkupsCurveNode_GetSurfaceCostFunctionType, METH_VARARGS,
   "V.GetSurfaceCostFunctionType() -> int\nC++: int GetSurfaceCostFunctionType()\n\nThe method that should be used to combine the distance with the\nscalar value. Uses the COST_FUNCTION_X enums from\nvtkSlicerDijkstraGraphGeodesicPath.\n"},
  {"SetSurfaceCostFunctionType", PyvtkMRMLMarkupsCurveNode_SetSurfaceCostFunctionType, METH_VARARGS,
   "V.SetSurfaceCostFunctionType(int)\nC++: void SetSurfaceCostFunctionType(int surfaceCostFunctionType)\n\n"},
  {"GetSurfaceCostFunctionTypeAsString", PyvtkMRMLMarkupsCurveNode_GetSurfaceCostFunctionTypeAsString, METH_VARARGS,
   "V.GetSurfaceCostFunctionTypeAsString(int) -> string\nC++: static const char *GetSurfaceCostFunctionTypeAsString(\n    int surfaceCostFunctionType)\n\n"},
  {"GetSurfaceCostFunctionTypeFromString", PyvtkMRMLMarkupsCurveNode_GetSurfaceCostFunctionTypeFromString, METH_VARARGS,
   "V.GetSurfaceCostFunctionTypeFromString(string) -> int\nC++: static int GetSurfaceCostFunctionTypeFromString(\n    const char *name)\n\n"},
  {"GetSurfaceDistanceWeightingFunction", PyvtkMRMLMarkupsCurveNode_GetSurfaceDistanceWeightingFunction, METH_VARARGS,
   "V.GetSurfaceDistanceWeightingFunction() -> string\nC++: const char *GetSurfaceDistanceWeightingFunction()\n\nThe scalar weight function that is used for modifying the weight\non each vertex. The the currently active point scalar array is\navailable as the \"activeScalar\" variable.\n"},
  {"SetSurfaceDistanceWeightingFunction", PyvtkMRMLMarkupsCurveNode_SetSurfaceDistanceWeightingFunction, METH_VARARGS,
   "V.SetSurfaceDistanceWeightingFunction(string)\nC++: void SetSurfaceDistanceWeightingFunction(\n    const char *function)\n\n"},
  {"GetNumberOfPointsPerInterpolatingSegment", PyvtkMRMLMarkupsCurveNode_GetNumberOfPointsPerInterpolatingSegment, METH_VARARGS,
   "V.GetNumberOfPointsPerInterpolatingSegment() -> int\nC++: int GetNumberOfPointsPerInterpolatingSegment()\n\nGet/set how many curve points are inserted between control\npoints. Higher values are recommended if distance between control\npoints is large.\n"},
  {"SetNumberOfPointsPerInterpolatingSegment", PyvtkMRMLMarkupsCurveNode_SetNumberOfPointsPerInterpolatingSegment, METH_VARARGS,
   "V.SetNumberOfPointsPerInterpolatingSegment(int)\nC++: void SetNumberOfPointsPerInterpolatingSegment(\n    int pointsPerSegment)\n\nGet/set how many curve points are inserted between control\npoints. Higher values are recommended if distance between control\npoints is large.\n"},
  {"UpdateAssignedAttribute", PyvtkMRMLMarkupsCurveNode_UpdateAssignedAttribute, METH_VARARGS,
   "V.UpdateAssignedAttribute()\nC++: virtual void UpdateAssignedAttribute() override;\n\nUpdate scalar range and update markups pipeline when the active\nscalar array is changed\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkMRMLMarkupsCurveNode_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkSlicerMarkupsModuleMRML.vtkMRMLMarkupsCurveNode", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkMRMLMarkupsCurveNode_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkMRMLMarkupsCurveNode_StaticNew()
{
  return vtkMRMLMarkupsCurveNode::New();
}

PyObject *PyvtkMRMLMarkupsCurveNode_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkMRMLMarkupsCurveNode_Type, PyvtkMRMLMarkupsCurveNode_Methods,
    "vtkMRMLMarkupsCurveNode",
 &PyvtkMRMLMarkupsCurveNode_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkMRMLMarkupsNode_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkMRMLMarkupsCurveNode(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkMRMLMarkupsCurveNode_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkMRMLMarkupsCurveNode", o) != 0)
  {
    Py_DECREF(o);
  }

}

