// python wrapper for vtkMRMLMarkupsROINode
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkMRMLMarkupsROINode.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkMRMLMarkupsROINode(PyObject *dict); }
extern "C" { PyObject *PyvtkMRMLMarkupsROINode_ClassNew(); }

#ifndef DECLARED_PyvtkMRMLMarkupsNode_ClassNew
extern "C" { PyObject *PyvtkMRMLMarkupsNode_ClassNew(); }
#define DECLARED_PyvtkMRMLMarkupsNode_ClassNew
#endif

static const char *PyvtkMRMLMarkupsROINode_Doc =
  "vtkMRMLMarkupsROINode - MRML node to represent an ROI markup\n\n"
  "Superclass: vtkMRMLMarkupsNode\n\n"
  "Coordinate systems used:\n"
  "- Local: Coordinate system of the markup node.\n"
  "- ROI: Coordinate system that the ROI is defined in. ROI is axis\n"
  "  aligned with center of ROI at (0,0,0).\n"
  "- World: Patient coordinate system (RAS)\n\n"
  "\\ingroup Slicer_QtModules_Markups\n\n";


static PyObject *
PyvtkMRMLMarkupsROINode_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkMRMLMarkupsROINode::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkMRMLMarkupsROINode::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkMRMLMarkupsROINode *tempr = vtkMRMLMarkupsROINode::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMRMLMarkupsROINode *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkMRMLMarkupsROINode::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkMRMLMarkupsROINode::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkMRMLMarkupsROINode::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetIcon(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetIcon");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetIcon() :
      op->vtkMRMLMarkupsROINode::GetIcon());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_CreateNodeInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateNodeInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMRMLNode *tempr = (ap.IsBound() ?
      op->CreateNodeInstance() :
      op->vtkMRMLMarkupsROINode::CreateNodeInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetNodeTagName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNodeTagName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetNodeTagName() :
      op->vtkMRMLMarkupsROINode::GetNodeTagName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_CopyContent(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CopyContent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  vtkMRMLNode *temp0 = nullptr;
  bool temp1 = true;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1, 2) &&
      ap.GetVTKObject(temp0, "vtkMRMLNode") &&
      (ap.NoArgsLeft() || ap.GetValue(temp1)))
  {
    if (ap.IsBound())
    {
      op->CopyContent(temp0, temp1);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::CopyContent(temp0, temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_HasCopyContent(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "HasCopyContent");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->HasCopyContent() :
      op->vtkMRMLMarkupsROINode::HasCopyContent());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetSize(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  size_t sizer = 3;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double *tempr = (ap.IsBound() ?
      op->GetSize() :
      op->vtkMRMLMarkupsROINode::GetSize());

    if (!ap.ErrorOccurred())
    {
      result = vtkPythonArgs::BuildTuple(tempr, sizer);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_SetSize_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    if (ap.IsBound())
    {
      op->SetSize(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::SetSize(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkMRMLMarkupsROINode_SetSize_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetSize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  double temp0;
  double temp1;
  double temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    if (ap.IsBound())
    {
      op->SetSize(temp0, temp1, temp2);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::SetSize(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkMRMLMarkupsROINode_SetSize(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 1:
      return PyvtkMRMLMarkupsROINode_SetSize_s1(self, args);
    case 3:
      return PyvtkMRMLMarkupsROINode_SetSize_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetSize");
  return nullptr;
}



static PyObject *
PyvtkMRMLMarkupsROINode_GetCenter(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCenter");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetCenter(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetCenter(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetCenterWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCenterWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetCenterWorld(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetCenterWorld(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_SetCenterWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCenterWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    if (ap.IsBound())
    {
      op->SetCenterWorld(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::SetCenterWorld(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_SetCenter(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCenter");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    if (ap.IsBound())
    {
      op->SetCenter(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::SetCenter(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetXAxisWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetXAxisWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetXAxisWorld(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetXAxisWorld(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetYAxisWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetYAxisWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetYAxisWorld(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetYAxisWorld(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetZAxisWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetZAxisWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetZAxisWorld(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetZAxisWorld(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetAxisWorld(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAxisWorld");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  int temp0;
  const size_t size1 = 3;
  double temp1[3];
  double save1[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetArray(temp1, size1))
  {
    vtkPythonArgs::Save(temp1, save1, size1);

    if (ap.IsBound())
    {
      op->GetAxisWorld(temp0, temp1);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetAxisWorld(temp0, temp1);
    }

    if (vtkPythonArgs::HasChanged(temp1, save1, size1) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(1, temp1, size1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetXAxisLocal(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetXAxisLocal");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetXAxisLocal(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetXAxisLocal(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetYAxisLocal(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetYAxisLocal");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetYAxisLocal(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetYAxisLocal(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetZAxisLocal(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetZAxisLocal");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetZAxisLocal(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetZAxisLocal(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetAxisLocal(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAxisLocal");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  int temp0;
  const size_t size1 = 3;
  double temp1[3];
  double save1[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetArray(temp1, size1))
  {
    vtkPythonArgs::Save(temp1, save1, size1);

    if (ap.IsBound())
    {
      op->GetAxisLocal(temp0, temp1);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetAxisLocal(temp0, temp1);
    }

    if (vtkPythonArgs::HasChanged(temp1, save1, size1) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(1, temp1, size1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetROIToLocalMatrix(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetROIToLocalMatrix");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMatrix4x4 *tempr = (ap.IsBound() ?
      op->GetROIToLocalMatrix() :
      op->vtkMRMLMarkupsROINode::GetROIToLocalMatrix());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetBoundsROI(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetBoundsROI");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 6;
  double temp0[6];
  double save0[6];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetBoundsROI(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetBoundsROI(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetROIType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetROIType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetROIType() :
      op->vtkMRMLMarkupsROINode::GetROIType());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_SetROIType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetROIType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetROIType(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::SetROIType(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetROITypeAsString(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetROITypeAsString");

  int temp0;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    const char *tempr = vtkMRMLMarkupsROINode::GetROITypeAsString(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetROITypeFromString(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetROITypeFromString");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkMRMLMarkupsROINode::GetROITypeFromString(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_UpdateROIFromControlPoints(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UpdateROIFromControlPoints");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UpdateROIFromControlPoints();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::UpdateROIFromControlPoints();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_UpdateBoxROIFromControlPoints(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UpdateBoxROIFromControlPoints");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UpdateBoxROIFromControlPoints();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::UpdateBoxROIFromControlPoints();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_UpdateBoundingBoxROIFromControlPoints(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UpdateBoundingBoxROIFromControlPoints");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UpdateBoundingBoxROIFromControlPoints();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::UpdateBoundingBoxROIFromControlPoints();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_UpdateControlPointsFromROI(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UpdateControlPointsFromROI");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UpdateControlPointsFromROI();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::UpdateControlPointsFromROI();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_UpdateControlPointsFromBoundingBoxROI(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UpdateControlPointsFromBoundingBoxROI");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UpdateControlPointsFromBoundingBoxROI();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::UpdateControlPointsFromBoundingBoxROI();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_UpdateControlPointsFromBoxROI(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UpdateControlPointsFromBoxROI");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UpdateControlPointsFromBoxROI();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::UpdateControlPointsFromBoxROI();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_OnTransformNodeReferenceChanged(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "OnTransformNodeReferenceChanged");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  vtkMRMLTransformNode *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMRMLTransformNode"))
  {
    if (ap.IsBound())
    {
      op->OnTransformNodeReferenceChanged(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::OnTransformNodeReferenceChanged(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_ProcessMRMLEvents(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ProcessMRMLEvents");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  vtkObject *temp0 = nullptr;
  unsigned long temp1;
  void  *temp2 = nullptr;
  Py_buffer pbuf2 = VTK_PYBUFFER_INITIALIZER;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetVTKObject(temp0, "vtkObject") &&
      ap.GetValue(temp1) &&
      ap.GetBuffer(temp2, &pbuf2))
  {
    if (ap.IsBound())
    {
      op->ProcessMRMLEvents(temp0, temp1, temp2);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::ProcessMRMLEvents(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

#if PY_VERSION_HEX >= 0x02060000
  if (pbuf2.obj != 0)
  {
    PyBuffer_Release(&pbuf2);
  }
#endif
  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_UpdateInteractionHandleToWorldMatrix(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UpdateInteractionHandleToWorldMatrix");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UpdateInteractionHandleToWorldMatrix();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::UpdateInteractionHandleToWorldMatrix();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_CreateDefaultStorageNode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateDefaultStorageNode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMRMLStorageNode *tempr = (ap.IsBound() ?
      op->CreateDefaultStorageNode() :
      op->vtkMRMLMarkupsROINode::CreateDefaultStorageNode());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_CreateDefaultDisplayNodes(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateDefaultDisplayNodes");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->CreateDefaultDisplayNodes();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::CreateDefaultDisplayNodes();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_SetXYZ_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetXYZ");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    int tempr = (ap.IsBound() ?
      op->SetXYZ(temp0) :
      op->vtkMRMLMarkupsROINode::SetXYZ(temp0));

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkMRMLMarkupsROINode_SetXYZ_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetXYZ");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  double temp0;
  double temp1;
  double temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    int tempr = (ap.IsBound() ?
      op->SetXYZ(temp0, temp1, temp2) :
      op->vtkMRMLMarkupsROINode::SetXYZ(temp0, temp1, temp2));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkMRMLMarkupsROINode_SetXYZ(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 1:
      return PyvtkMRMLMarkupsROINode_SetXYZ_s1(self, args);
    case 3:
      return PyvtkMRMLMarkupsROINode_SetXYZ_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetXYZ");
  return nullptr;
}



static PyObject *
PyvtkMRMLMarkupsROINode_GetXYZ(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetXYZ");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    bool tempr = (ap.IsBound() ?
      op->GetXYZ(temp0) :
      op->vtkMRMLMarkupsROINode::GetXYZ(temp0));

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_SetRadiusXYZ_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetRadiusXYZ");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->SetRadiusXYZ(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::SetRadiusXYZ(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkMRMLMarkupsROINode_SetRadiusXYZ_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetRadiusXYZ");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  double temp0;
  double temp1;
  double temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    if (ap.IsBound())
    {
      op->SetRadiusXYZ(temp0, temp1, temp2);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::SetRadiusXYZ(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkMRMLMarkupsROINode_SetRadiusXYZ(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 1:
      return PyvtkMRMLMarkupsROINode_SetRadiusXYZ_s1(self, args);
    case 3:
      return PyvtkMRMLMarkupsROINode_SetRadiusXYZ_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetRadiusXYZ");
  return nullptr;
}



static PyObject *
PyvtkMRMLMarkupsROINode_GetRadiusXYZ(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRadiusXYZ");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  const size_t size0 = 3;
  double temp0[3];
  double save0[3];
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetArray(temp0, size0))
  {
    vtkPythonArgs::Save(temp0, save0, size0);

    if (ap.IsBound())
    {
      op->GetRadiusXYZ(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetRadiusXYZ(temp0);
    }

    if (vtkPythonArgs::HasChanged(temp0, save0, size0) &&
        !ap.ErrorOccurred())
    {
      ap.SetArray(0, temp0, size0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetTransformedPlanes(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTransformedPlanes");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  vtkPlanes *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkPlanes"))
  {
    if (ap.IsBound())
    {
      op->GetTransformedPlanes(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::GetTransformedPlanes(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_SetInsideOut(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetInsideOut");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetInsideOut(temp0);
    }
    else
    {
      op->vtkMRMLMarkupsROINode::SetInsideOut(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_GetInsideOut(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetInsideOut");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetInsideOut() :
      op->vtkMRMLMarkupsROINode::GetInsideOut());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_InsideOutOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "InsideOutOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->InsideOutOn();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::InsideOutOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkMRMLMarkupsROINode_InsideOutOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "InsideOutOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkMRMLMarkupsROINode *op = static_cast<vtkMRMLMarkupsROINode *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->InsideOutOff();
    }
    else
    {
      op->vtkMRMLMarkupsROINode::InsideOutOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkMRMLMarkupsROINode_Methods[] = {
  {"IsTypeOf", PyvtkMRMLMarkupsROINode_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkMRMLMarkupsROINode_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkMRMLMarkupsROINode_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkMRMLMarkupsROINode\nC++: static vtkMRMLMarkupsROINode *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkMRMLMarkupsROINode_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkMRMLMarkupsROINode\nC++: vtkMRMLMarkupsROINode *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkMRMLMarkupsROINode_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkMRMLMarkupsROINode_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetIcon", PyvtkMRMLMarkupsROINode_GetIcon, METH_VARARGS,
   "V.GetIcon() -> string\nC++: const char *GetIcon() override;\n\n"},
  {"CreateNodeInstance", PyvtkMRMLMarkupsROINode_CreateNodeInstance, METH_VARARGS,
   "V.CreateNodeInstance() -> vtkMRMLNode\nC++: vtkMRMLNode *CreateNodeInstance() override;\n\nMRMLNode methods\n"},
  {"GetNodeTagName", PyvtkMRMLMarkupsROINode_GetNodeTagName, METH_VARARGS,
   "V.GetNodeTagName() -> string\nC++: const char *GetNodeTagName() override;\n\nGet node XML tag name (like Volume, Model)\n"},
  {"CopyContent", PyvtkMRMLMarkupsROINode_CopyContent, METH_VARARGS,
   "V.CopyContent(vtkMRMLNode, bool)\nC++: void CopyContent(vtkMRMLNode *node, bool deepCopy=true)\n    override;\n\nCopy node content (excludes basic data, such as name and node\nreferences).\n\\sa vtkMRMLNode::CopyContent\n"},
  {"HasCopyContent", PyvtkMRMLMarkupsROINode_HasCopyContent, METH_VARARGS,
   "V.HasCopyContent() -> bool\nC++: bool HasCopyContent() override;\n\nReturns true if the class supports deep and shallow copying node\n    content.\n"},
  {"GetSize", PyvtkMRMLMarkupsROINode_GetSize, METH_VARARGS,
   "V.GetSize() -> (float, float, float)\nC++: virtual double *GetSize()\n\nLength of the ROI sides\n"},
  {"SetSize", PyvtkMRMLMarkupsROINode_SetSize, METH_VARARGS,
   "V.SetSize((float, float, float))\nC++: void SetSize(const double size[3])\nV.SetSize(float, float, float)\nC++: void SetSize(double x, double y, double z)\n\n"},
  {"GetCenter", PyvtkMRMLMarkupsROINode_GetCenter, METH_VARARGS,
   "V.GetCenter([float, float, float])\nC++: void GetCenter(double center[3])\n\nCenter of the ROI\n"},
  {"GetCenterWorld", PyvtkMRMLMarkupsROINode_GetCenterWorld, METH_VARARGS,
   "V.GetCenterWorld([float, float, float])\nC++: void GetCenterWorld(double center[3])\n\n"},
  {"SetCenterWorld", PyvtkMRMLMarkupsROINode_SetCenterWorld, METH_VARARGS,
   "V.SetCenterWorld((float, float, float))\nC++: void SetCenterWorld(const double center[3])\n\n"},
  {"SetCenter", PyvtkMRMLMarkupsROINode_SetCenter, METH_VARARGS,
   "V.SetCenter((float, float, float))\nC++: void SetCenter(const double center[3])\n\n"},
  {"GetXAxisWorld", PyvtkMRMLMarkupsROINode_GetXAxisWorld, METH_VARARGS,
   "V.GetXAxisWorld([float, float, float])\nC++: void GetXAxisWorld(double axis_World[3])\n\nThe directional axis of the ROI that are defined by\nROIToLocalMatrix.\n\\sa GetROIToLocalMatrix()\n"},
  {"GetYAxisWorld", PyvtkMRMLMarkupsROINode_GetYAxisWorld, METH_VARARGS,
   "V.GetYAxisWorld([float, float, float])\nC++: void GetYAxisWorld(double axis_World[3])\n\n"},
  {"GetZAxisWorld", PyvtkMRMLMarkupsROINode_GetZAxisWorld, METH_VARARGS,
   "V.GetZAxisWorld([float, float, float])\nC++: void GetZAxisWorld(double axis_World[3])\n\n"},
  {"GetAxisWorld", PyvtkMRMLMarkupsROINode_GetAxisWorld, METH_VARARGS,
   "V.GetAxisWorld(int, [float, float, float])\nC++: void GetAxisWorld(int axisIndex, double axis_World[3])\n\n"},
  {"GetXAxisLocal", PyvtkMRMLMarkupsROINode_GetXAxisLocal, METH_VARARGS,
   "V.GetXAxisLocal([float, float, float])\nC++: void GetXAxisLocal(double axis_Local[3])\n\n"},
  {"GetYAxisLocal", PyvtkMRMLMarkupsROINode_GetYAxisLocal, METH_VARARGS,
   "V.GetYAxisLocal([float, float, float])\nC++: void GetYAxisLocal(double axis_Local[3])\n\n"},
  {"GetZAxisLocal", PyvtkMRMLMarkupsROINode_GetZAxisLocal, METH_VARARGS,
   "V.GetZAxisLocal([float, float, float])\nC++: void GetZAxisLocal(double axis_Local[3])\n\n"},
  {"GetAxisLocal", PyvtkMRMLMarkupsROINode_GetAxisLocal, METH_VARARGS,
   "V.GetAxisLocal(int, [float, float, float])\nC++: void GetAxisLocal(int axisIndex, double axis_Local[3])\n\n"},
  {"GetROIToLocalMatrix", PyvtkMRMLMarkupsROINode_GetROIToLocalMatrix, METH_VARARGS,
   "V.GetROIToLocalMatrix() -> vtkMatrix4x4\nC++: vtkMatrix4x4 *GetROIToLocalMatrix()\n\n4x4 matrix defining the ROI center and axis directions within the\nlocal coordinate system.\n"},
  {"GetBoundsROI", PyvtkMRMLMarkupsROINode_GetBoundsROI, METH_VARARGS,
   "V.GetBoundsROI([float, float, float, float, float, float])\nC++: void GetBoundsROI(double bounds[6])\n\nGet the bounds of the ROI in the ROI coordinate system.\n"},
  {"GetROIType", PyvtkMRMLMarkupsROINode_GetROIType, METH_VARARGS,
   "V.GetROIType() -> int\nC++: virtual int GetROIType()\n\nROIType represents the method that is used to calculate the size\nof the ROI. BOX ROI does not require control points to define a\nregion, while the size of a BOUNDING_BOX ROI will be defined by\nthe control points.\n"},
  {"SetROIType", PyvtkMRMLMarkupsROINode_SetROIType, METH_VARARGS,
   "V.SetROIType(int)\nC++: void SetROIType(int roiType)\n\n"},
  {"GetROITypeAsString", PyvtkMRMLMarkupsROINode_GetROITypeAsString, METH_VARARGS,
   "V.GetROITypeAsString(int) -> string\nC++: static const char *GetROITypeAsString(int roiType)\n\n"},
  {"GetROITypeFromString", PyvtkMRMLMarkupsROINode_GetROITypeFromString, METH_VARARGS,
   "V.GetROITypeFromString(string) -> int\nC++: static int GetROITypeFromString(const char *roiType)\n\n"},
  {"UpdateROIFromControlPoints", PyvtkMRMLMarkupsROINode_UpdateROIFromControlPoints, METH_VARARGS,
   "V.UpdateROIFromControlPoints()\nC++: virtual void UpdateROIFromControlPoints()\n\nCalculate the ROI dimensions from the control points\n"},
  {"UpdateBoxROIFromControlPoints", PyvtkMRMLMarkupsROINode_UpdateBoxROIFromControlPoints, METH_VARARGS,
   "V.UpdateBoxROIFromControlPoints()\nC++: virtual void UpdateBoxROIFromControlPoints()\n\n"},
  {"UpdateBoundingBoxROIFromControlPoints", PyvtkMRMLMarkupsROINode_UpdateBoundingBoxROIFromControlPoints, METH_VARARGS,
   "V.UpdateBoundingBoxROIFromControlPoints()\nC++: virtual void UpdateBoundingBoxROIFromControlPoints()\n\n"},
  {"UpdateControlPointsFromROI", PyvtkMRMLMarkupsROINode_UpdateControlPointsFromROI, METH_VARARGS,
   "V.UpdateControlPointsFromROI()\nC++: virtual void UpdateControlPointsFromROI()\n\nCalculate the position of control points from the ROI\n"},
  {"UpdateControlPointsFromBoundingBoxROI", PyvtkMRMLMarkupsROINode_UpdateControlPointsFromBoundingBoxROI, METH_VARARGS,
   "V.UpdateControlPointsFromBoundingBoxROI()\nC++: virtual void UpdateControlPointsFromBoundingBoxROI()\n\n"},
  {"UpdateControlPointsFromBoxROI", PyvtkMRMLMarkupsROINode_UpdateControlPointsFromBoxROI, METH_VARARGS,
   "V.UpdateControlPointsFromBoxROI()\nC++: virtual void UpdateControlPointsFromBoxROI()\n\n"},
  {"OnTransformNodeReferenceChanged", PyvtkMRMLMarkupsROINode_OnTransformNodeReferenceChanged, METH_VARARGS,
   "V.OnTransformNodeReferenceChanged(vtkMRMLTransformNode)\nC++: void OnTransformNodeReferenceChanged(\n    vtkMRMLTransformNode *transformNode) override;\n\nReimplemented to recalculate InteractionHandleToWorld matrix when\nparent transform is changed.\n"},
  {"ProcessMRMLEvents", PyvtkMRMLMarkupsROINode_ProcessMRMLEvents, METH_VARARGS,
   "V.ProcessMRMLEvents(vtkObject, int, void)\nC++: void ProcessMRMLEvents(vtkObject *caller,\n    unsigned long event, void *callData) override;\n\nAlternative method to propagate events generated in Display nodes\n"},
  {"UpdateInteractionHandleToWorldMatrix", PyvtkMRMLMarkupsROINode_UpdateInteractionHandleToWorldMatrix, METH_VARARGS,
   "V.UpdateInteractionHandleToWorldMatrix()\nC++: void UpdateInteractionHandleToWorldMatrix() override;\n\nUpdate the InteractionHandleToWorldMatrix based on the ROIToLocal\nand LocalToWorld transforms.\n"},
  {"CreateDefaultStorageNode", PyvtkMRMLMarkupsROINode_CreateDefaultStorageNode, METH_VARARGS,
   "V.CreateDefaultStorageNode() -> vtkMRMLStorageNode\nC++: vtkMRMLStorageNode *CreateDefaultStorageNode() override;\n\nCreate default storage node or nullptr if does not have one\n"},
  {"CreateDefaultDisplayNodes", PyvtkMRMLMarkupsROINode_CreateDefaultDisplayNodes, METH_VARARGS,
   "V.CreateDefaultDisplayNodes()\nC++: void CreateDefaultDisplayNodes() override;\n\nCreate default storage node or nullptr if does not have one\n"},
  {"SetXYZ", PyvtkMRMLMarkupsROINode_SetXYZ, METH_VARARGS,
   "V.SetXYZ([float, float, float]) -> int\nC++: int SetXYZ(double center[3])\nV.SetXYZ(float, float, float) -> int\nC++: int SetXYZ(double x, double y, double z)\n\nLegacy vtkMRMLAnnotationROINode methods\n\nLegacy method from vtkMRMLAnnotationROINode Get/Set for ROI\nPosition in RAS cooridnates Note: The ROI Position is the center\nof the ROI Old API: void SetXYZ(double X, double Y, double Z);\nvoid SetXYZ(double* XYZ); vtkGetVectorMacro(XYZ,double,3);\ndouble* GetXYZ() {return this->GetControlPointCoordinates(0);}\n\\sa SetCenter(), GetCenter()\n"},
  {"GetXYZ", PyvtkMRMLMarkupsROINode_GetXYZ, METH_VARARGS,
   "V.GetXYZ([float, float, float]) -> bool\nC++: bool GetXYZ(double center[3])\n\n"},
  {"SetRadiusXYZ", PyvtkMRMLMarkupsROINode_SetRadiusXYZ, METH_VARARGS,
   "V.SetRadiusXYZ([float, float, float])\nC++: void SetRadiusXYZ(double radiusXYZ[3])\nV.SetRadiusXYZ(float, float, float)\nC++: void SetRadiusXYZ(double x, double y, double z)\n\nLegacy method from vtkMRMLAnnotationROINode Get/Set for radius of\nthe ROI in RAS cooridnates Old API: void SetRadiusXYZ(double\nRadiusX, double RadiusY, double RadiusZ); void\nSetRadiusXYZ(double* RadiusXYZ);\nvtkGetVectorMacro(RadiusXYZ,double,3);\n\\sa SetSize(), GetSize()\n"},
  {"GetRadiusXYZ", PyvtkMRMLMarkupsROINode_GetRadiusXYZ, METH_VARARGS,
   "V.GetRadiusXYZ([float, float, float])\nC++: void GetRadiusXYZ(double radiusXYZ[3])\n\n"},
  {"GetTransformedPlanes", PyvtkMRMLMarkupsROINode_GetTransformedPlanes, METH_VARARGS,
   "V.GetTransformedPlanes(vtkPlanes)\nC++: void GetTransformedPlanes(vtkPlanes *planes)\n\nLegacy method from vtkMRMLAnnotationROINode\n"},
  {"SetInsideOut", PyvtkMRMLMarkupsROINode_SetInsideOut, METH_VARARGS,
   "V.SetInsideOut(bool)\nC++: virtual void SetInsideOut(bool _arg)\n\nLegacy method from vtkMRMLAnnotationROINode Indicates if the ROI\nbox is inside out\n"},
  {"GetInsideOut", PyvtkMRMLMarkupsROINode_GetInsideOut, METH_VARARGS,
   "V.GetInsideOut() -> bool\nC++: virtual bool GetInsideOut()\n\n"},
  {"InsideOutOn", PyvtkMRMLMarkupsROINode_InsideOutOn, METH_VARARGS,
   "V.InsideOutOn()\nC++: virtual void InsideOutOn()\n\n"},
  {"InsideOutOff", PyvtkMRMLMarkupsROINode_InsideOutOff, METH_VARARGS,
   "V.InsideOutOff()\nC++: virtual void InsideOutOff()\n\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkMRMLMarkupsROINode_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkSlicerMarkupsModuleMRML.vtkMRMLMarkupsROINode", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkMRMLMarkupsROINode_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkMRMLMarkupsROINode_StaticNew()
{
  return vtkMRMLMarkupsROINode::New();
}

PyObject *PyvtkMRMLMarkupsROINode_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkMRMLMarkupsROINode_Type, PyvtkMRMLMarkupsROINode_Methods,
    "vtkMRMLMarkupsROINode",
 &PyvtkMRMLMarkupsROINode_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkMRMLMarkupsNode_ClassNew();

  PyObject *d = pytype->tp_dict;
  PyObject *o;

  for (int c = 0; c < 17; c++)
  {
    static const struct { const char *name; int value; }
      constants[17] = {
        { "ROITypeBox", vtkMRMLMarkupsROINode::ROITypeBox },
        { "ROITypeBoundingBox", vtkMRMLMarkupsROINode::ROITypeBoundingBox },
        { "ROIType_Last", vtkMRMLMarkupsROINode::ROIType_Last },
        { "HandleLFace", vtkMRMLMarkupsROINode::HandleLFace },
        { "HandleRFace", vtkMRMLMarkupsROINode::HandleRFace },
        { "HandlePFace", vtkMRMLMarkupsROINode::HandlePFace },
        { "HandleAFace", vtkMRMLMarkupsROINode::HandleAFace },
        { "HandleIFace", vtkMRMLMarkupsROINode::HandleIFace },
        { "HandleSFace", vtkMRMLMarkupsROINode::HandleSFace },
        { "HandleLPICorner", vtkMRMLMarkupsROINode::HandleLPICorner },
        { "HandleRPICorner", vtkMRMLMarkupsROINode::HandleRPICorner },
        { "HandleLAICorner", vtkMRMLMarkupsROINode::HandleLAICorner },
        { "HandleRAICorner", vtkMRMLMarkupsROINode::HandleRAICorner },
        { "HandleLPSCorner", vtkMRMLMarkupsROINode::HandleLPSCorner },
        { "HandleRPSCorner", vtkMRMLMarkupsROINode::HandleRPSCorner },
        { "HandleLASCorner", vtkMRMLMarkupsROINode::HandleLASCorner },
        { "HandleRASCorner", vtkMRMLMarkupsROINode::HandleRASCorner },
      };

    o = PyInt_FromLong(constants[c].value);
    if (o)
    {
      PyDict_SetItemString(d, constants[c].name, o);
      Py_DECREF(o);
    }
  }

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkMRMLMarkupsROINode(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkMRMLMarkupsROINode_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkMRMLMarkupsROINode", o) != 0)
  {
    Py_DECREF(o);
  }

}

