// python wrapper for vtkSlicerClosedCurveWidget
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkSlicerClosedCurveWidget.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkSlicerClosedCurveWidget(PyObject *dict); }
extern "C" { PyObject *PyvtkSlicerClosedCurveWidget_ClassNew(); }

#ifndef DECLARED_PyvtkSlicerMarkupsWidget_ClassNew
extern "C" { PyObject *PyvtkSlicerMarkupsWidget_ClassNew(); }
#define DECLARED_PyvtkSlicerMarkupsWidget_ClassNew
#endif

static const char *PyvtkSlicerClosedCurveWidget_Doc =
  "vtkSlicerClosedCurveWidget - create a curve with a set of N points\n\n"
  "Superclass: vtkSlicerMarkupsWidget\n\n"
  "The vtkSlicerClosedCurveWidget is used to create a closed curve\n"
  "widget with a set of N points. The widget handles all processing of\n"
  "widget events (that are triggered by VTK events). The\n"
  "vtkSlicerCurveRepresentation is responsible for all placement of the\n"
  "points, and curve manipulation. This is done through a main helper\n"
  "class: vtkPointPlacer. The representation is also responsible for\n"
  "drawing the points.\n\n"
  "@par Event Bindings: By default, the widget responds to the following\n"
  "VTK events (i.e., it watches the vtkRenderWindowInteractor for these\n"
  "events):\n\n\n"
  "  LeftButtonPressEvent - triggers a Select event\n"
  "  Alt + LeftButtonPressEvent - triggers a Rotate event\n"
  "  MiddleButtonPressEvent - triggers a Translate event\n"
  "  RightButtonPressEvent - triggers a Pick event\n"
  "  Alt + RightButtonPressEvent - triggers a Scale event\n\n\n"
  "  MouseMoveEvent - triggers a Move event\n\n\n"
  "  LeftButtonReleaseEvent - triggers an EndAction event\n"
  "  MiddleButtonReleaseEvent - triggers an EndAction event\n"
  "  RightButtonReleaseEvent - triggers an EndAction event\n\n\n"
  "  LeftButtonDoubleClickEvent - triggers an Pick event\n"
  "  MiddleButtonDoubleClickEvent - triggers an Pick event\n"
  "  RightButtonDoubleClickEvent - triggers an Pick event\n\n\n"
  "  Delete key event - triggers a Delete event\n"
  "  Shift + Delete key event - triggers a Reset event \n\n";


static PyObject *
PyvtkSlicerClosedCurveWidget_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkSlicerClosedCurveWidget::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSlicerClosedCurveWidget_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSlicerClosedCurveWidget *op = static_cast<vtkSlicerClosedCurveWidget *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkSlicerClosedCurveWidget::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSlicerClosedCurveWidget_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkSlicerClosedCurveWidget *tempr = vtkSlicerClosedCurveWidget::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSlicerClosedCurveWidget_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSlicerClosedCurveWidget *op = static_cast<vtkSlicerClosedCurveWidget *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkSlicerClosedCurveWidget *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkSlicerClosedCurveWidget::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkSlicerClosedCurveWidget_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkSlicerClosedCurveWidget::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSlicerClosedCurveWidget_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSlicerClosedCurveWidget *op = static_cast<vtkSlicerClosedCurveWidget *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkSlicerClosedCurveWidget::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSlicerClosedCurveWidget_CreateDefaultRepresentation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateDefaultRepresentation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSlicerClosedCurveWidget *op = static_cast<vtkSlicerClosedCurveWidget *>(vp);

  vtkMRMLMarkupsDisplayNode *temp0 = nullptr;
  vtkMRMLAbstractViewNode *temp1 = nullptr;
  vtkRenderer *temp2 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetVTKObject(temp0, "vtkMRMLMarkupsDisplayNode") &&
      ap.GetVTKObject(temp1, "vtkMRMLAbstractViewNode") &&
      ap.GetVTKObject(temp2, "vtkRenderer"))
  {
    if (ap.IsBound())
    {
      op->CreateDefaultRepresentation(temp0, temp1, temp2);
    }
    else
    {
      op->vtkSlicerClosedCurveWidget::CreateDefaultRepresentation(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkSlicerClosedCurveWidget_Methods[] = {
  {"IsTypeOf", PyvtkSlicerClosedCurveWidget_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkSlicerClosedCurveWidget_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkSlicerClosedCurveWidget_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkSlicerClosedCurveWidget\nC++: static vtkSlicerClosedCurveWidget *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkSlicerClosedCurveWidget_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkSlicerClosedCurveWidget\nC++: vtkSlicerClosedCurveWidget *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkSlicerClosedCurveWidget_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkSlicerClosedCurveWidget_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"CreateDefaultRepresentation", PyvtkSlicerClosedCurveWidget_CreateDefaultRepresentation, METH_VARARGS,
   "V.CreateDefaultRepresentation(vtkMRMLMarkupsDisplayNode,\n    vtkMRMLAbstractViewNode, vtkRenderer)\nC++: void CreateDefaultRepresentation(\n    vtkMRMLMarkupsDisplayNode *markupsDisplayNode,\n    vtkMRMLAbstractViewNode *viewNode, vtkRenderer *renderer)\n    override;\n\nCreate the default widget representation and initializes the\nwidget and representation.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkSlicerClosedCurveWidget_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkSlicerMarkupsModuleVTKWidgets.vtkSlicerClosedCurveWidget", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkSlicerClosedCurveWidget_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkSlicerClosedCurveWidget_StaticNew()
{
  return vtkSlicerClosedCurveWidget::New();
}

PyObject *PyvtkSlicerClosedCurveWidget_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkSlicerClosedCurveWidget_Type, PyvtkSlicerClosedCurveWidget_Methods,
    "vtkSlicerClosedCurveWidget",
 &PyvtkSlicerClosedCurveWidget_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkSlicerMarkupsWidget_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkSlicerClosedCurveWidget(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkSlicerClosedCurveWidget_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkSlicerClosedCurveWidget", o) != 0)
  {
    Py_DECREF(o);
  }

}

